@@ -110,9 +110,12 @@ class Selenium(Scraper):
         if timeout > 0:
             try:
                 ignored_exceptions = (NoSuchElementException, StaleElementReferenceException)
-                return len(WebDriverWait(driver=element, timeout=timeout, ignored_exceptions=ignored_exceptions).until(
-                    EC.presence_of_element_located((By.XPATH, path))) > 0
-                )
+                element = WebDriverWait(driver=element, timeout=timeout, ignored_exceptions=ignored_exceptions).until(
+                    EC.presence_of_element_located((By.XPATH, path)))
+                
+                if isinstance(element, list): return len(element) > 0
+                else: return element is not None
+
             except Exception as ex:
                 if is_error is True: raise NoSuchElementException(msg=f'Element with xpath {path} was not found')
                 else: return False
